===================
OpenWrt ubus client
===================

This is a python client for https://openwrt.org/docs/techref/ubus[OpenWrt micro bus].  It uses the https://openwrt.org/docs/techref/ubus#access_to_ubus_over_http[http jsonrpc] protocol.  This requires the `uhttpd-mod-ubus` package to be installed.